@@ -9,17 +9,25 @@
 #
 package Moo::Role::Lax;
 {
-  $Moo::Role::Lax::VERSION = '0.10';
+  $Moo::Role::Lax::VERSION = '0.11';
 }
 
 #ABSTRACT: By default Moo::Role turns all warnings to fatal warnings. This module is exactly the same as Moo::Role, except that it doesn't turn all warnings to fatal warnings in the calling module.
 
+
+use strict;
+use warnings;
+
 require strictures;
 my $orig = \&strictures::import;
-require Moo;
+require Moo::Role;
 sub import {
-    *strictures::import = sub { *strictures::import = $orig };
-    splice @_, 0, 1, 'Moo::Role'; goto &Moo::import;
+    no warnings 'redefine';
+    *strictures::import = sub {
+        strict->import; warnings->import;
+        *strictures::import = $orig;
+    };
+    splice @_, 0, 1, 'Moo::Role'; goto &Moo::Role::import;
 }
 
 1
@@ -36,7 +44,12 @@ Moo::Role::Lax - By default Moo::Role turns all warnings to fatal warnings. This
 
 =head1 VERSION
 
-version 0.10
+version 0.11
+
+=head1 SYNOPSIS
+
+  # instead of use Moo::Role;
+  use Moo::Role::Lax;
 
 =head1 AUTHOR
 
